<?php
namespace Recruitment\Repository;

use Application\Repository\HrisRepository;
use Zend\Db\Adapter\AdapterInterface;
use Application\Model\Model;
use Zend\Db\Sql\Sql;
use Application\Helper\EntityHelper;
use Recruitment\Model\AdmitModel;
use Zend\Db\Sql\Expression;

Class AdmitRepository extends HrisRepository{
    public function __construct(AdapterInterface $adapter, $tablename = null)
    {
        parent::__construct($adapter, AdmitModel::TABLE_NAME);
    }
    public function add(Model $options_data) 
    {
        $addData=$options_data->getArrayCopyForDB();
        $this->tableGateway->insert($addData);
    }
    
    public function edit(Model $model, $id)
    {
        $array = $model->getArrayCopyForDB();
        $this->tableGateway->update($array, [AdmitModel::ADMIT_SETUP_ID => $id]);
    }
    public function fetch()
    {
        $sql = "SELECT *  FROM HRIS_REC_ADMIT_SETUP WHERE ADMIT_SETUP_ID = 1";
        $statement = $this->adapter->query($sql);
        $result    = $statement->execute();
        return $result->current();
    }

    public function delete(Model $model ,$id)
    {
        $array = $model->getArrayCopyForDB();
        $deleted_dt = date('Y-m-d');
        $rawsql = "UPDATE HRIS_REC_SKILL  SET STATUS = 'D', DELETED_BY = {$array['DELETED_BY']}, DELETED_DT = '{$deleted_dt}' WHERE SKILL_ID = {$id}";
        // echo '<pre>'; print_r($rawsql); die;
        return EntityHelper::rawQueryResult($this->adapter, $rawsql);
    }

    public function allApplicationUsers($stage_id, $vacancy_id) {

        $sql = "SELECT 
                    A.APPLICATION_ID,A.USER_ID,A.APPLICATION_TYPE,
                    P.ROLL_NO,
                    RV.AD_NO, RV.AD_NO_NEPALI,
                    HUR.FIRST_NAME,HUR.MIDDLE_NAME,HUR.LAST_NAME,
                    RUR.CITIZENSHIP_NO, RUR.CTZ_ISSUE_DATE,
                    RUR.USER_ID,
                    D.DISTRICT_NAME, D.DISTRICT_NAME_NEPALI,
                    AD.DOC_PATH AS PROFILE,
                    ADD.DOC_PATH AS SIGNATURE,
                    A.FIRST_PAPER_VENUE_ASSIGN_ID,
                    A.SECOND_PAPER_VENUE_ASSIGN_ID,
                    HRVA.START_TIME AS FIRST_START_TIME, HRVA.EXAM_DATE AS FIRST_EXAM_DATE,
                    HRVAA.START_TIME AS SECOND_START_TIME, HRVAA.EXAM_DATE AS SECOND_EXAM_DATE ,
                    HRVS.VENUE_NAME AS FIRST_VENUE_NAME,
                    HRVSS.VENUE_NAME AS SECOND_VENUE_NAME,


                    HD.DESIGNATION_TITLE, HD.DESIGNATION_NTITLE,
                    HFL.FUNCTIONAL_LEVEL_EDESC,
                    HST.SERVICE_TYPE_NAME, HST.SERVICE_TYPE_NAME_NEPALI,
                    HET.SERVICE_EVENT_NAME, HET.SERVICE_EVENT_NAME_NEPALI

                FROM HRIS_REC_VACANCY_APPLICATION A
                LEFT JOIN HRIS_REC_VENUE_ASSIGN HRVA ON HRVA.VENUE_ASSIGN_ID = A.FIRST_PAPER_VENUE_ASSIGN_ID
                LEFT JOIN HRIS_REC_VENUE_SETUP HRVS ON HRVS.VENUE_SETUP_ID = HRVA.VENUE_SETUP_ID
                LEFT JOIN HRIS_REC_VENUE_ASSIGN HRVAA ON HRVAA.VENUE_ASSIGN_ID = A.SECOND_PAPER_VENUE_ASSIGN_ID
                LEFT JOIN HRIS_REC_VENUE_SETUP HRVSS ON HRVSS.VENUE_SETUP_ID = HRVAA.VENUE_SETUP_ID
                LEFT JOIN HRIS_REC_VACANCY RV ON RV.VACANCY_ID = A.AD_NO
                LEFT JOIN HRIS_REC_APPLICATION_PERSONAL P ON P.APPLICATION_ID = A.APPLICATION_ID
                LEFT JOIN HRIS_REC_APPLICATION_DOCUMENTS AD ON (AD.APPLICATION_ID = A.APPLICATION_ID AND AD.DOC_FOLDER = 'photograph')
                LEFT JOIN HRIS_REC_APPLICATION_DOCUMENTS ADD ON (ADD.APPLICATION_ID = A.APPLICATION_ID AND ADD.DOC_FOLDER = 'signature')
                LEFT JOIN HRIS_REC_VACANCY_USERS HUR ON HUR.USER_ID = A.USER_ID
                LEFT JOIN HRIS_REC_USERS_REGISTRATION  RUR ON RUR.USER_ID = HUR.USER_ID
                LEFT JOIN HRIS_DISTRICTS D ON D.DISTRICT_ID = RUR.CTZ_ISSUE_DISTRICT_ID
                LEFT JOIN HRIS_DESIGNATIONS AS HD ON RV.POSITION_ID = HD.DESIGNATION_ID
                LEFT JOIN HRIS_DEPARTMENTS AS HVD ON RV.DEPARTMENT_ID = HVD.DEPARTMENT_ID
                LEFT JOIN HRIS_SERVICE_TYPES AS HST ON HST.SERVICE_TYPE_ID = RV.SERVICE_TYPES_ID
                LEFT JOIN HRIS_REC_SERVICE_EVENTS_TYPES AS HET ON HET.SERVICE_EVENT_ID = RV.SERVICE_EVENTS_ID
                LEFT JOIN HRIS_FUNCTIONAL_LEVELS AS HFL ON HFL.FUNCTIONAL_LEVEL_ID = RV.LEVEL_ID
                WHERE   A.STAGE_ID = {$stage_id} 
                    AND A.AD_NO IN ({$vacancy_id})
                ORDER BY P.ROLL_NO_EDESC ASC";

        $result = $this->rawQuery($sql);
        return $result;

    }

    public function allApplicationUsersIn($stage_id, $vacancy_id) {

        $sql = "SELECT 
                    A.APPLICATION_ID,A.USER_ID,A.APPLICATION_TYPE,
                    P.ROLL_NO,
                    RV.AD_NO, RV.AD_NO_NEPALI,
                    E.FIRST_NAME,E.MIDDLE_NAME,E.LAST_NAME,
                    E.ID_CITIZENSHIP_NO AS CITIZENSHIP_NO,
                    RO.OPTION_NDESC,
                    HUR.USER_ID,
                    AD.FILE_PATH AS PROFILE,
                    ADD.DOC_PATH || ADD.DOC_NEW_NAME AS SIGNATURE,
                    


                    HD.DESIGNATION_TITLE, HD.DESIGNATION_NTITLE,
                    HFL.FUNCTIONAL_LEVEL_EDESC,
                    HST.SERVICE_TYPE_NAME, HST.SERVICE_TYPE_NAME_NEPALI,
                    HET.SERVICE_EVENT_NAME, HET.SERVICE_EVENT_NAME_NEPALI

                FROM HRIS_REC_VACANCY_APPLICATION A
                LEFT JOIN HRIS_REC_VACANCY RV ON RV.VACANCY_ID = A.AD_NO
                LEFT JOIN HRIS_REC_APPLICATION_PERSONAL P ON P.APPLICATION_ID = A.APPLICATION_ID
                LEFT JOIN HRIS_REC_OPTIONS RO ON RO.OPTION_ID = P.INCLUSION_ID
                LEFT JOIN HRIS_REC_APPLICATION_DOCUMENTS ADD ON (ADD.APPLICATION_ID = A.APPLICATION_ID AND ADD.DOC_FOLDER = 'Signature')
                LEFT JOIN HRIS_USERS AS HUR ON HUR.USER_ID = A.USER_ID
                LEFT JOIN HRIS_EMPLOYEES AS E ON E.EMPLOYEE_ID = HUR.EMPLOYEE_ID
                LEFT JOIN HRIS_EMPLOYEE_FILE AS AD ON AD.FILE_CODE = E.PROFILE_PICTURE_ID
                LEFT JOIN HRIS_REC_USERS_REGISTRATION AS RUR ON RUR.USER_ID = HUR.USER_ID
                LEFT JOIN HRIS_DESIGNATIONS AS HD ON RV.POSITION_ID = HD.DESIGNATION_ID
                LEFT JOIN HRIS_DEPARTMENTS AS HVD ON RV.DEPARTMENT_ID = HVD.DEPARTMENT_ID
                LEFT JOIN HRIS_SERVICE_TYPES AS HST ON HST.SERVICE_TYPE_ID = RV.SERVICE_TYPES_ID
                LEFT JOIN HRIS_REC_SERVICE_EVENTS_TYPES AS HET ON HET.SERVICE_EVENT_ID = RV.SERVICE_EVENTS_ID
                LEFT JOIN HRIS_FUNCTIONAL_LEVELS AS HFL ON HFL.FUNCTIONAL_LEVEL_ID = RV.LEVEL_ID
                WHERE   A.STAGE_ID = {$stage_id} 
                    AND A.AD_NO IN ({$vacancy_id})
                ORDER BY P.ROLL_NO_EDESC ASC";

        $result = $this->rawQuery($sql);
        return $result;

    }

    public function allApplicationUsersInVenue($stage_id, $vacancy_id) {

        $sql = "SELECT 
                    A.APPLICATION_ID,A.USER_ID,A.APPLICATION_TYPE,
                    P.ROLL_NO,
                    RV.AD_NO, RV.AD_NO_NEPALI,
                    E.FIRST_NAME,E.MIDDLE_NAME,E.LAST_NAME,
                    E.ID_CITIZENSHIP_NO AS CITIZENSHIP_NO,
                    RO.OPTION_NDESC,
                    HUR.USER_ID,
                    AD.FILE_PATH AS PROFILE,
                    ADD.DOC_PATH || ADD.DOC_NEW_NAME AS SIGNATURE,
                    A.FIRST_PAPER_VENUE_ASSIGN_ID,
                    A.SECOND_PAPER_VENUE_ASSIGN_ID,
                    HRVA.START_TIME AS FIRST_START_TIME, HRVA.EXAM_DATE AS FIRST_EXAM_DATE,
                    HRVAA.START_TIME AS SECOND_START_TIME, HRVAA.EXAM_DATE AS SECOND_EXAM_DATE ,
                    HRVS.VENUE_NAME AS FIRST_VENUE_NAME,
                    HRVSS.VENUE_NAME AS SECOND_VENUE_NAME,
                    


                    HD.DESIGNATION_TITLE, HD.DESIGNATION_NTITLE,
                    HFL.FUNCTIONAL_LEVEL_EDESC,
                    HST.SERVICE_TYPE_NAME, HST.SERVICE_TYPE_NAME_NEPALI,
                    HET.SERVICE_EVENT_NAME, HET.SERVICE_EVENT_NAME_NEPALI

                FROM HRIS_REC_VACANCY_APPLICATION A
                LEFT JOIN HRIS_REC_VENUE_ASSIGN HRVA ON HRVA.VENUE_ASSIGN_ID = A.FIRST_PAPER_VENUE_ASSIGN_ID
                LEFT JOIN HRIS_REC_VENUE_SETUP HRVS ON HRVS.VENUE_SETUP_ID = HRVA.VENUE_SETUP_ID
                LEFT JOIN HRIS_REC_VENUE_ASSIGN HRVAA ON HRVAA.VENUE_ASSIGN_ID = A.SECOND_PAPER_VENUE_ASSIGN_ID
                LEFT JOIN HRIS_REC_VENUE_SETUP HRVSS ON HRVSS.VENUE_SETUP_ID = HRVAA.VENUE_SETUP_ID
                LEFT JOIN HRIS_REC_VACANCY RV ON RV.VACANCY_ID = A.AD_NO
                LEFT JOIN HRIS_REC_APPLICATION_PERSONAL P ON P.APPLICATION_ID = A.APPLICATION_ID
                LEFT JOIN HRIS_REC_OPTIONS RO ON RO.OPTION_ID = P.INCLUSION_ID
                LEFT JOIN HRIS_REC_APPLICATION_DOCUMENTS ADD ON (ADD.APPLICATION_ID = A.APPLICATION_ID AND ADD.DOC_FOLDER = 'Signature')
                LEFT JOIN HRIS_USERS AS HUR ON HUR.USER_ID = A.USER_ID
                LEFT JOIN HRIS_EMPLOYEES AS E ON E.EMPLOYEE_ID = HUR.EMPLOYEE_ID
                LEFT JOIN HRIS_EMPLOYEE_FILE AS AD ON AD.FILE_CODE = E.PROFILE_PICTURE_ID
                LEFT JOIN HRIS_REC_USERS_REGISTRATION AS RUR ON RUR.USER_ID = HUR.USER_ID
                LEFT JOIN HRIS_DESIGNATIONS AS HD ON RV.POSITION_ID = HD.DESIGNATION_ID
                LEFT JOIN HRIS_DEPARTMENTS AS HVD ON RV.DEPARTMENT_ID = HVD.DEPARTMENT_ID
                LEFT JOIN HRIS_SERVICE_TYPES AS HST ON HST.SERVICE_TYPE_ID = RV.SERVICE_TYPES_ID
                LEFT JOIN HRIS_REC_SERVICE_EVENTS_TYPES AS HET ON HET.SERVICE_EVENT_ID = RV.SERVICE_EVENTS_ID
                LEFT JOIN HRIS_FUNCTIONAL_LEVELS AS HFL ON HFL.FUNCTIONAL_LEVEL_ID = RV.LEVEL_ID
                WHERE   A.STAGE_ID = {$stage_id} 
                    AND A.AD_NO IN ({$vacancy_id})
                ORDER BY P.ROLL_NO_EDESC ASC";

        $result = $this->rawQuery($sql);
        return $result;

    }

    public function admitCardInclusion($uid, $appid) 
    {

        if (!empty($uid) AND !empty($appid)) {


        $query  = "SELECT 
                        P.INCLUSION_ID, A.AD_NO, V.VACANCY_NO
                    
                    FROM HRIS_REC_APPLICATION_PERSONAL AS P
                    
                    LEFT JOIN HRIS_REC_VACANCY_APPLICATION AS A ON A.APPLICATION_ID = P.APPLICATION_ID
                    LEFT JOIN HRIS_REC_VACANCY AS V ON V.VACANCY_ID = A.AD_NO
                    WHERE P.USER_ID = $uid and P.APPLICATION_ID = $appid";

        // echo "<pre>";
        // print_r($query);
        // die;

        $statement = $this->adapter->query($query);
        $result    = $statement->execute();
        $inclusion = $result->current();

        // echo "<pre>";
        // print_r($inclusion);
        // die;
        $vacancy_no   = $inclusion['VACANCY_NO'];
        $inclusion_id = $inclusion['INCLUSION_ID'];
        $statement1 = "SELECT 
                        STRING_AGG(V.AD_NO,',') AS AD_NO,
                        STRING_AGG(V.AD_NO_NEPALI,',') AS AD_NO_NEPALI,
                        STRING_AGG(O.OPTION_EDESC,',') AS OPTION_EDESC,
                        STRING_AGG(O.OPTION_NDESC,',') AS OPTION_NDESC

                      FROM HRIS_REC_VACANCY AS V

                      LEFT JOIN HRIS_REC_OPTIONS AS O ON O.OPTION_ID = V.INCLUSION_ID
                      WHERE V.VACANCY_NO = $vacancy_no AND V.INCLUSION_ID IN ($inclusion_id) GROUP BY V.VACANCY_NO"
                      ;

        // echo "<pre>";
        // print_r($statement1);
        // die;
        $s = $this->adapter->query($statement1);
        $result1    = $s->execute();
        return $result1->current();
        }
        return false;
    }


    public function getAllPersonal() 
    {
        $sql = "SELECT * FROM HRIS_REC_APPLICATION_PERSONAL WHERE ROLL_NO IS NOT NULL";

        $result = $this->rawQuery($sql);
        return $result;

    }

    public function update_data($data, $id)
    {
        $sql = "UPDATE HRIS_REC_APPLICATION_PERSONAL SET ROLL_NO_EDESC = $data WHERE APPLICATION_ID = $id";

        $result = $this->rawQuery($sql);
        return true;
    }

    public function getnepaliname($uid)
    {
        $statement1 = "SELECT 
                        *

                      FROM HRIS_REC_VACANCY_USER_NEPALI 
                      WHERE USER_ID = $uid AND APPLICATION_TYPE = 'OPEN'"
                      ;

        // echo "<pre>";
        // print_r($statement1);
        // die;
        $s = $this->adapter->query($statement1);
        $result1    = $s->execute();
        return $result1->current();
        
    }

    public function getnepalinameInternal($uid)
    {
        $statement1 = "SELECT 
                        *

                      FROM HRIS_REC_VACANCY_USER_NEPALI 
                      WHERE USER_ID = $uid AND APPLICATION_TYPE = 'INTERNAL'"
                      ;

        // echo "<pre>";
        // print_r($statement1);
        // die;
        $s = $this->adapter->query($statement1);
        $result1    = $s->execute();
        return $result1->current();
        
    }
}